@@ -139,17 +139,16 @@ impl DebugCategory {
     #[doc(alias = "get_description")]
     #[doc(alias = "gst_debug_category_get_description")]
     pub fn description<'a>(self) -> Option<&'a str> {
-        match self.0 {
-            Some(cat) => unsafe {
-                let ptr = ffi::gst_debug_category_get_description(cat.as_ptr());
+        let cat = self.0?;
 
-                if ptr.is_null() {
-                    None
-                } else {
-                    Some(CStr::from_ptr(ptr).to_str().unwrap())
-                }
-            },
-            None => None,
+        unsafe {
+            let ptr = ffi::gst_debug_category_get_description(cat.as_ptr());
+
+            if ptr.is_null() {
+                None
+            } else {
+                Some(CStr::from_ptr(ptr).to_str().unwrap())
+            }
         }
     }
 
@@ -253,6 +252,33 @@ impl DebugCategory {
     pub fn all_categories() -> glib::SList<DebugCategory> {
         unsafe { glib::SList::from_glib_container_static(ffi::gst_debug_get_all_categories()) }
     }
+
+    #[cfg(any(feature = "v1_18", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+    #[doc(alias = "gst_debug_log_get_line")]
+    pub fn get_line(
+        &self,
+        level: crate::DebugLevel,
+        file: &str,
+        module: &str,
+        line: u32,
+        object: Option<&LoggedObject>,
+        message: &DebugMessage,
+    ) -> Option<glib::GString> {
+        let cat = self.0?;
+
+        unsafe {
+            from_glib_full(ffi::gst_debug_log_get_line(
+                cat.as_ptr(),
+                level.into_glib(),
+                file.to_glib_none().0,
+                module.to_glib_none().0,
+                line as i32,
+                object.map(|o| o.as_ptr()).unwrap_or(ptr::null_mut()),
+                message.0.as_ptr(),
+            ))
+        }
+    }
 }
 
 unsafe impl Sync for DebugCategory {}
