@@ -68,6 +68,11 @@ impl MessageRef {
         }
     }
 
+    #[doc(alias = "gst_message_has_name")]
+    pub fn has_name(&self, name: &str) -> bool {
+        self.structure().map_or(false, |s| s.has_name(name))
+    }
+
     pub fn view(&self) -> MessageView {
         let type_ = unsafe { (*self.as_ptr()).type_ };
 
@@ -109,14 +114,24 @@ impl MessageRef {
             ffi::GST_MESSAGE_HAVE_CONTEXT => MessageView::HaveContext(HaveContext(self)),
             ffi::GST_MESSAGE_DEVICE_ADDED => MessageView::DeviceAdded(DeviceAdded(self)),
             ffi::GST_MESSAGE_DEVICE_REMOVED => MessageView::DeviceRemoved(DeviceRemoved(self)),
+            #[cfg(any(feature = "v1_10", feature = "dox"))]
+            ffi::GST_MESSAGE_REDIRECT => MessageView::Redirect(Redirect(self)),
+            #[cfg(any(feature = "v1_10", feature = "dox"))]
             ffi::GST_MESSAGE_PROPERTY_NOTIFY => MessageView::PropertyNotify(PropertyNotify(self)),
+            #[cfg(any(feature = "v1_10", feature = "dox"))]
             ffi::GST_MESSAGE_STREAM_COLLECTION => {
                 MessageView::StreamCollection(StreamCollection(self))
             }
+            #[cfg(any(feature = "v1_10", feature = "dox"))]
             ffi::GST_MESSAGE_STREAMS_SELECTED => {
                 MessageView::StreamsSelected(StreamsSelected(self))
             }
+            #[cfg(any(feature = "v1_16", feature = "dox"))]
             ffi::GST_MESSAGE_DEVICE_CHANGED => MessageView::DeviceChanged(DeviceChanged(self)),
+            #[cfg(any(feature = "v1_18", feature = "dox"))]
+            ffi::GST_MESSAGE_INSTANT_RATE_REQUEST => {
+                MessageView::InstantRateRequest(InstantRateRequest(self))
+            }
             _ => MessageView::Other,
         }
     }
@@ -168,6 +183,7 @@ impl fmt::Debug for MessageRef {
 }
 
 #[derive(Debug)]
+#[non_exhaustive]
 pub enum MessageView<'a> {
     Eos(Eos<'a>),
     Error(Error<'a>),
@@ -202,13 +218,25 @@ pub enum MessageView<'a> {
     HaveContext(HaveContext<'a>),
     DeviceAdded(DeviceAdded<'a>),
     DeviceRemoved(DeviceRemoved<'a>),
+    #[cfg(any(feature = "v1_10", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     PropertyNotify(PropertyNotify<'a>),
+    #[cfg(any(feature = "v1_10", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     StreamCollection(StreamCollection<'a>),
+    #[cfg(any(feature = "v1_10", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     StreamsSelected(StreamsSelected<'a>),
+    #[cfg(any(feature = "v1_10", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     Redirect(Redirect<'a>),
+    #[cfg(any(feature = "v1_16", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
     DeviceChanged(DeviceChanged<'a>),
+    #[cfg(any(feature = "v1_18", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+    InstantRateRequest(InstantRateRequest<'a>),
     Other,
-    __NonExhaustive,
 }
 
 macro_rules! declare_concrete_message(
@@ -228,6 +256,7 @@ macro_rules! declare_concrete_message(
 
 declare_concrete_message!(Eos);
 impl<'a> Eos<'a> {
+    #[doc(alias = "gst_message_new_eos")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Message {
         skip_assert_initialized!();
@@ -242,6 +271,7 @@ impl<'a> Eos<'a> {
 
 declare_concrete_message!(Error);
 impl<'a> Error<'a> {
+    #[doc(alias = "gst_message_new_error")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<T: MessageErrorDomain>(error: T, message: &str) -> Message {
         skip_assert_initialized!();
@@ -266,6 +296,7 @@ impl<'a> Error<'a> {
     }
 
     #[doc(alias = "get_debug")]
+    #[doc(alias = "gst_message_parse_error")]
     pub fn debug(&self) -> Option<String> {
         unsafe {
             let mut debug = ptr::null_mut();
@@ -297,6 +328,7 @@ impl<'a> Error<'a> {
 
 declare_concrete_message!(Warning);
 impl<'a> Warning<'a> {
+    #[doc(alias = "gst_message_new_warning")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<T: MessageErrorDomain>(error: T, message: &str) -> Message {
         skip_assert_initialized!();
@@ -309,6 +341,7 @@ impl<'a> Warning<'a> {
     }
 
     #[doc(alias = "get_error")]
+    #[doc(alias = "gst_message_parse_warning")]
     pub fn error(&self) -> glib::Error {
         unsafe {
             let mut error = ptr::null_mut();
@@ -320,6 +353,7 @@ impl<'a> Warning<'a> {
     }
 
     #[doc(alias = "get_debug")]
+    #[doc(alias = "gst_message_parse_warning")]
     pub fn debug(&self) -> Option<String> {
         unsafe {
             let mut debug = ptr::null_mut();
@@ -333,12 +367,12 @@ impl<'a> Warning<'a> {
     #[cfg(any(feature = "v1_10", feature = "dox"))]
     #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     #[doc(alias = "get_details")]
-    #[doc(alias = "gst_message_parse_error_details")]
+    #[doc(alias = "gst_message_parse_warning_details")]
     pub fn details(&self) -> Option<&StructureRef> {
         unsafe {
             let mut details = ptr::null();
 
-            ffi::gst_message_parse_error_details(self.as_mut_ptr(), &mut details);
+            ffi::gst_message_parse_warning_details(self.as_mut_ptr(), &mut details);
 
             if details.is_null() {
                 None
@@ -351,6 +385,7 @@ impl<'a> Warning<'a> {
 
 declare_concrete_message!(Info);
 impl<'a> Info<'a> {
+    #[doc(alias = "gst_message_new_info")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<T: MessageErrorDomain>(error: T, message: &str) -> Message {
         skip_assert_initialized!();
@@ -363,6 +398,7 @@ impl<'a> Info<'a> {
     }
 
     #[doc(alias = "get_error")]
+    #[doc(alias = "gst_message_parse_info")]
     pub fn error(&self) -> glib::Error {
         unsafe {
             let mut error = ptr::null_mut();
@@ -374,6 +410,7 @@ impl<'a> Info<'a> {
     }
 
     #[doc(alias = "get_debug")]
+    #[doc(alias = "gst_message_parse_info")]
     pub fn debug(&self) -> Option<String> {
         unsafe {
             let mut debug = ptr::null_mut();
@@ -387,12 +424,12 @@ impl<'a> Info<'a> {
     #[cfg(any(feature = "v1_10", feature = "dox"))]
     #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     #[doc(alias = "get_details")]
-    #[doc(alias = "gst_message_parse_error_details")]
+    #[doc(alias = "gst_message_parse_info_details")]
     pub fn details(&self) -> Option<&StructureRef> {
         unsafe {
             let mut details = ptr::null();
 
-            ffi::gst_message_parse_error_details(self.as_mut_ptr(), &mut details);
+            ffi::gst_message_parse_info_details(self.as_mut_ptr(), &mut details);
 
             if details.is_null() {
                 None
@@ -405,6 +442,7 @@ impl<'a> Info<'a> {
 
 declare_concrete_message!(Tag);
 impl<'a> Tag<'a> {
+    #[doc(alias = "gst_message_new_tag")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(tags: &TagList) -> Message {
         skip_assert_initialized!();
@@ -417,6 +455,7 @@ impl<'a> Tag<'a> {
     }
 
     #[doc(alias = "get_tags")]
+    #[doc(alias = "gst_message_parse_tag")]
     pub fn tags(&self) -> TagList {
         unsafe {
             let mut tags = ptr::null_mut();
@@ -428,6 +467,7 @@ impl<'a> Tag<'a> {
 
 declare_concrete_message!(Buffering);
 impl<'a> Buffering<'a> {
+    #[doc(alias = "gst_message_new_buffering")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(percent: i32) -> Message {
         skip_assert_initialized!();
@@ -440,6 +480,7 @@ impl<'a> Buffering<'a> {
     }
 
     #[doc(alias = "get_percent")]
+    #[doc(alias = "gst_message_parse_buffering")]
     pub fn percent(&self) -> i32 {
         unsafe {
             let mut p = mem::MaybeUninit::uninit();
@@ -477,6 +518,7 @@ impl<'a> Buffering<'a> {
 
 declare_concrete_message!(StateChanged);
 impl<'a> StateChanged<'a> {
+    #[doc(alias = "gst_message_new_state_changed")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(old: crate::State, new: crate::State, pending: crate::State) -> Message {
         skip_assert_initialized!();
@@ -493,6 +535,7 @@ impl<'a> StateChanged<'a> {
     }
 
     #[doc(alias = "get_old")]
+    #[doc(alias = "gst_message_parse_state_changed")]
     pub fn old(&self) -> crate::State {
         unsafe {
             let mut state = mem::MaybeUninit::uninit();
@@ -509,6 +552,7 @@ impl<'a> StateChanged<'a> {
     }
 
     #[doc(alias = "get_current")]
+    #[doc(alias = "gst_message_parse_state_changed")]
     pub fn current(&self) -> crate::State {
         unsafe {
             let mut state = mem::MaybeUninit::uninit();
@@ -525,6 +569,7 @@ impl<'a> StateChanged<'a> {
     }
 
     #[doc(alias = "get_pending")]
+    #[doc(alias = "gst_message_parse_state_changed")]
     pub fn pending(&self) -> crate::State {
         unsafe {
             let mut state = mem::MaybeUninit::uninit();
@@ -543,6 +588,7 @@ impl<'a> StateChanged<'a> {
 
 declare_concrete_message!(StateDirty);
 impl<'a> StateDirty<'a> {
+    #[doc(alias = "gst_message_new_state_dirty")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Message {
         skip_assert_initialized!();
@@ -557,6 +603,7 @@ impl<'a> StateDirty<'a> {
 
 declare_concrete_message!(StepDone);
 impl<'a> StepDone<'a> {
+    #[doc(alias = "gst_message_new_step_done")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<V: Into<GenericFormattedValue>>(
         amount: V,
@@ -597,6 +644,7 @@ impl<'a> StepDone<'a> {
         )
     }
 
+    #[doc(alias = "gst_message_parse_step_done")]
     pub fn get(
         &self,
     ) -> (
@@ -647,6 +695,7 @@ impl<'a> StepDone<'a> {
 
 declare_concrete_message!(ClockProvide);
 impl<'a> ClockProvide<'a> {
+    #[doc(alias = "gst_message_new_clock_provide")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(clock: &crate::Clock, ready: bool) -> Message {
         skip_assert_initialized!();
@@ -671,6 +720,7 @@ impl<'a> ClockProvide<'a> {
     }
 
     #[doc(alias = "get_ready")]
+    #[doc(alias = "gst_message_parse_clock_provide")]
     pub fn is_ready(&self) -> bool {
         unsafe {
             let mut ready = mem::MaybeUninit::uninit();
@@ -688,6 +738,7 @@ impl<'a> ClockProvide<'a> {
 
 declare_concrete_message!(ClockLost);
 impl<'a> ClockLost<'a> {
+    #[doc(alias = "gst_message_new_clock_lost")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(clock: &crate::Clock) -> Message {
         skip_assert_initialized!();
@@ -714,6 +765,7 @@ impl<'a> ClockLost<'a> {
 
 declare_concrete_message!(NewClock);
 impl<'a> NewClock<'a> {
+    #[doc(alias = "gst_message_new_new_clock")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(clock: &crate::Clock) -> Message {
         skip_assert_initialized!();
@@ -740,6 +792,7 @@ impl<'a> NewClock<'a> {
 
 declare_concrete_message!(StructureChange);
 impl<'a> StructureChange<'a> {
+    #[doc(alias = "gst_message_new_structure_change")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(type_: crate::StructureChangeType, owner: &crate::Element, busy: bool) -> Message {
         skip_assert_initialized!();
@@ -755,6 +808,7 @@ impl<'a> StructureChange<'a> {
         StructureChangeBuilder::new(type_, owner, busy)
     }
 
+    #[doc(alias = "gst_message_parse_structure_change")]
     pub fn get(&self) -> (crate::StructureChangeType, crate::Element, bool) {
         unsafe {
             let mut type_ = mem::MaybeUninit::uninit();
@@ -779,6 +833,7 @@ impl<'a> StructureChange<'a> {
 
 declare_concrete_message!(StreamStatus);
 impl<'a> StreamStatus<'a> {
+    #[doc(alias = "gst_message_new_stream_status")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(type_: crate::StreamStatusType, owner: &crate::Element) -> Message {
         skip_assert_initialized!();
@@ -790,6 +845,7 @@ impl<'a> StreamStatus<'a> {
         StreamStatusBuilder::new(type_, owner)
     }
 
+    #[doc(alias = "gst_message_parse_stream_status")]
     pub fn get(&self) -> (crate::StreamStatusType, crate::Element) {
         unsafe {
             let mut type_ = mem::MaybeUninit::uninit();
@@ -814,6 +870,7 @@ impl<'a> StreamStatus<'a> {
 
 declare_concrete_message!(Application);
 impl<'a> Application<'a> {
+    #[doc(alias = "gst_message_new_application")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(structure: crate::Structure) -> Message {
         skip_assert_initialized!();
@@ -828,6 +885,7 @@ impl<'a> Application<'a> {
 
 declare_concrete_message!(Element);
 impl<'a> Element<'a> {
+    #[doc(alias = "gst_message_new_element")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(structure: crate::Structure) -> Message {
         skip_assert_initialized!();
@@ -842,6 +900,7 @@ impl<'a> Element<'a> {
 
 declare_concrete_message!(SegmentStart);
 impl<'a> SegmentStart<'a> {
+    #[doc(alias = "gst_message_new_segment_start")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<V: Into<GenericFormattedValue>>(position: V) -> Message {
         skip_assert_initialized!();
@@ -854,6 +913,7 @@ impl<'a> SegmentStart<'a> {
         SegmentStartBuilder::new(position)
     }
 
+    #[doc(alias = "gst_message_parse_segment_start")]
     pub fn get(&self) -> GenericFormattedValue {
         unsafe {
             let mut format = mem::MaybeUninit::uninit();
@@ -872,6 +932,7 @@ impl<'a> SegmentStart<'a> {
 
 declare_concrete_message!(SegmentDone);
 impl<'a> SegmentDone<'a> {
+    #[doc(alias = "gst_message_new_segment_done")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<V: Into<GenericFormattedValue>>(position: V) -> Message {
         skip_assert_initialized!();
@@ -884,6 +945,7 @@ impl<'a> SegmentDone<'a> {
         SegmentDoneBuilder::new(position)
     }
 
+    #[doc(alias = "gst_message_parse_segment_done")]
     pub fn get(&self) -> GenericFormattedValue {
         unsafe {
             let mut format = mem::MaybeUninit::uninit();
@@ -902,6 +964,7 @@ impl<'a> SegmentDone<'a> {
 
 declare_concrete_message!(DurationChanged);
 impl<'a> DurationChanged<'a> {
+    #[doc(alias = "gst_message_new_duration_changed")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Message {
         skip_assert_initialized!();
@@ -916,6 +979,7 @@ impl<'a> DurationChanged<'a> {
 
 declare_concrete_message!(Latency);
 impl<'a> Latency<'a> {
+    #[doc(alias = "gst_message_new_latency")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Message {
         skip_assert_initialized!();
@@ -930,6 +994,7 @@ impl<'a> Latency<'a> {
 
 declare_concrete_message!(AsyncStart);
 impl<'a> AsyncStart<'a> {
+    #[doc(alias = "gst_message_new_async_start")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Message {
         skip_assert_initialized!();
@@ -944,6 +1009,7 @@ impl<'a> AsyncStart<'a> {
 
 declare_concrete_message!(AsyncDone);
 impl<'a> AsyncDone<'a> {
+    #[doc(alias = "gst_message_new_async_done")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(running_time: impl Into<Option<crate::ClockTime>>) -> Message {
         skip_assert_initialized!();
@@ -956,6 +1022,7 @@ impl<'a> AsyncDone<'a> {
     }
 
     #[doc(alias = "get_running_time")]
+    #[doc(alias = "gst_message_parse_async_done")]
     pub fn running_time(&self) -> Option<crate::ClockTime> {
         unsafe {
             let mut running_time = mem::MaybeUninit::uninit();
@@ -969,6 +1036,7 @@ impl<'a> AsyncDone<'a> {
 
 declare_concrete_message!(RequestState);
 impl<'a> RequestState<'a> {
+    #[doc(alias = "gst_message_new_request_state")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(state: crate::State) -> Message {
         skip_assert_initialized!();
@@ -981,6 +1049,7 @@ impl<'a> RequestState<'a> {
     }
 
     #[doc(alias = "get_requested_state")]
+    #[doc(alias = "gst_message_parse_request_state")]
     pub fn requested_state(&self) -> crate::State {
         unsafe {
             let mut state = mem::MaybeUninit::uninit();
@@ -994,6 +1063,7 @@ impl<'a> RequestState<'a> {
 
 declare_concrete_message!(StepStart);
 impl<'a> StepStart<'a> {
+    #[doc(alias = "gst_message_new_step_start")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new<V: Into<GenericFormattedValue>>(
         active: bool,
@@ -1017,6 +1087,7 @@ impl<'a> StepStart<'a> {
         StepStartBuilder::new(active, amount.into(), rate, flush, intermediate)
     }
 
+    #[doc(alias = "gst_message_parse_step_start")]
     pub fn get(&self) -> (bool, GenericFormattedValue, f64, bool, bool) {
         unsafe {
             let mut active = mem::MaybeUninit::uninit();
@@ -1052,6 +1123,7 @@ impl<'a> StepStart<'a> {
 
 declare_concrete_message!(Qos);
 impl<'a> Qos<'a> {
+    #[doc(alias = "gst_message_new_qos")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(
         live: bool,
@@ -1074,6 +1146,7 @@ impl<'a> Qos<'a> {
         QosBuilder::new(live)
     }
 
+    #[doc(alias = "gst_message_parse_qos")]
     pub fn get(
         &self,
     ) -> (
@@ -1163,6 +1236,7 @@ impl<'a> Qos<'a> {
 
 declare_concrete_message!(Progress);
 impl<'a> Progress<'a> {
+    #[doc(alias = "gst_message_new_progress")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(type_: crate::ProgressType, code: &'a str, text: &'a str) -> Message {
         skip_assert_initialized!();
@@ -1178,6 +1252,7 @@ impl<'a> Progress<'a> {
         ProgressBuilder::new(type_, code, text)
     }
 
+    #[doc(alias = "gst_message_parse_progress")]
     pub fn get(&self) -> (crate::ProgressType, &'a str, &'a str) {
         unsafe {
             let mut type_ = mem::MaybeUninit::uninit();
@@ -1203,6 +1278,7 @@ declare_concrete_message!(Toc);
 impl<'a> Toc<'a> {
     // FIXME could use false for updated as default
     // Even better: use an enum for updated so that it is more explicit than true / false
+    #[doc(alias = "gst_message_new_toc")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(toc: &crate::Toc, updated: bool) -> Message {
         skip_assert_initialized!();
@@ -1228,6 +1304,7 @@ impl<'a> Toc<'a> {
 
 declare_concrete_message!(ResetTime);
 impl<'a> ResetTime<'a> {
+    #[doc(alias = "gst_message_new_reset_time")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(running_time: crate::ClockTime) -> Message {
         skip_assert_initialized!();
@@ -1240,6 +1317,7 @@ impl<'a> ResetTime<'a> {
     }
 
     #[doc(alias = "get_running_time")]
+    #[doc(alias = "gst_message_parse_reset_time")]
     pub fn running_time(&self) -> crate::ClockTime {
         unsafe {
             let mut running_time = mem::MaybeUninit::uninit();
@@ -1253,6 +1331,7 @@ impl<'a> ResetTime<'a> {
 
 declare_concrete_message!(StreamStart);
 impl<'a> StreamStart<'a> {
+    #[doc(alias = "gst_message_new_stream_start")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Message {
         skip_assert_initialized!();
@@ -1289,6 +1368,7 @@ impl<'a> StreamStart<'a> {
 
 declare_concrete_message!(NeedContext);
 impl<'a> NeedContext<'a> {
+    #[doc(alias = "gst_message_new_need_context")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(context_type: &str) -> Message {
         skip_assert_initialized!();
@@ -1315,6 +1395,7 @@ impl<'a> NeedContext<'a> {
 
 declare_concrete_message!(HaveContext);
 impl<'a> HaveContext<'a> {
+    #[doc(alias = "gst_message_new_have_context")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(context: crate::Context) -> Message {
         skip_assert_initialized!();
@@ -1339,6 +1420,7 @@ impl<'a> HaveContext<'a> {
 
 declare_concrete_message!(DeviceAdded);
 impl<'a> DeviceAdded<'a> {
+    #[doc(alias = "gst_message_new_device_added")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(device: &crate::Device) -> Message {
         skip_assert_initialized!();
@@ -1365,6 +1447,7 @@ impl<'a> DeviceAdded<'a> {
 
 declare_concrete_message!(DeviceRemoved);
 impl<'a> DeviceRemoved<'a> {
+    #[doc(alias = "gst_message_new_device_removed")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(device: &crate::Device) -> Message {
         skip_assert_initialized!();
@@ -1389,25 +1472,25 @@ impl<'a> DeviceRemoved<'a> {
     }
 }
 
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 declare_concrete_message!(PropertyNotify);
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 impl<'a> PropertyNotify<'a> {
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+    #[doc(alias = "gst_message_new_property_notify")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(property_name: &str) -> Message {
         skip_assert_initialized!();
         Self::builder(property_name).build()
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     pub fn builder(property_name: &str) -> PropertyNotifyBuilder {
         assert_initialized_main_thread!();
         PropertyNotifyBuilder::new(property_name)
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+    #[doc(alias = "gst_message_parse_property_notify")]
     pub fn get(&self) -> (Object, &str, Option<&'a glib::Value>) {
         unsafe {
             let mut object = ptr::null_mut();
@@ -1434,25 +1517,24 @@ impl<'a> PropertyNotify<'a> {
     }
 }
 
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 declare_concrete_message!(StreamCollection);
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 impl<'a> StreamCollection<'a> {
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+    #[doc(alias = "gst_message_new_stream_collection")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(collection: &crate::StreamCollection) -> Message {
         skip_assert_initialized!();
         Self::builder(collection).build()
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     pub fn builder(collection: &crate::StreamCollection) -> StreamCollectionBuilder {
         assert_initialized_main_thread!();
         StreamCollectionBuilder::new(collection)
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     #[doc(alias = "get_stream_collection")]
     #[doc(alias = "gst_message_parse_stream_collection")]
     pub fn stream_collection(&self) -> crate::StreamCollection {
@@ -1466,26 +1548,26 @@ impl<'a> StreamCollection<'a> {
     }
 }
 
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 declare_concrete_message!(StreamsSelected);
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 impl<'a> StreamsSelected<'a> {
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+    #[doc(alias = "gst_message_new_streams_selected")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(collection: &crate::StreamCollection) -> Message {
         skip_assert_initialized!();
         Self::builder(collection).build()
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     pub fn builder(collection: &crate::StreamCollection) -> StreamsSelectedBuilder {
         assert_initialized_main_thread!();
         StreamsSelectedBuilder::new(collection)
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     #[doc(alias = "get_stream_collection")]
+    #[doc(alias = "gst_message_parse_streams_selected")]
     pub fn stream_collection(&self) -> crate::StreamCollection {
         unsafe {
             let mut collection = ptr::null_mut();
@@ -1496,8 +1578,6 @@ impl<'a> StreamsSelected<'a> {
         }
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     #[doc(alias = "get_streams")]
     #[doc(alias = "gst_message_streams_selected_get_size")]
     #[doc(alias = "gst_message_streams_selected_get_stream")]
@@ -1517,27 +1597,27 @@ impl<'a> StreamsSelected<'a> {
     }
 }
 
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 declare_concrete_message!(Redirect);
+#[cfg(any(feature = "v1_10", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
 impl<'a> Redirect<'a> {
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+    #[doc(alias = "gst_message_new_redirect")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(location: &str) -> Message {
         skip_assert_initialized!();
         Self::builder(location).build()
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     pub fn builder(location: &str) -> RedirectBuilder {
         assert_initialized_main_thread!();
         RedirectBuilder::new(location)
     }
 
-    #[cfg(any(feature = "v1_10", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
     #[doc(alias = "get_entries")]
     #[doc(alias = "gst_message_get_num_redirect_entries")]
+    #[doc(alias = "gst_message_parse_redirect_entry")]
     pub fn entries(&self) -> Vec<(&str, Option<TagList>, Option<&StructureRef>)> {
         unsafe {
             let n = ffi::gst_message_get_num_redirect_entries(self.as_mut_ptr());
@@ -1573,18 +1653,19 @@ impl<'a> Redirect<'a> {
     }
 }
 
+#[cfg(any(feature = "v1_16", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
 declare_concrete_message!(DeviceChanged);
+#[cfg(any(feature = "v1_16", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
 impl<'a> DeviceChanged<'a> {
-    #[cfg(any(feature = "v1_16", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+    #[doc(alias = "gst_message_new_device_changed")]
     #[allow(clippy::new_ret_no_self)]
     pub fn new(device: &'a crate::Device, changed_device: &'a crate::Device) -> Message {
         skip_assert_initialized!();
         Self::builder(device, changed_device).build()
     }
 
-    #[cfg(any(feature = "v1_16", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
     pub fn builder(
         device: &'a crate::Device,
         changed_device: &'a crate::Device,
@@ -1593,8 +1674,6 @@ impl<'a> DeviceChanged<'a> {
         DeviceChangedBuilder::new(device, changed_device)
     }
 
-    #[cfg(any(feature = "v1_16", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
     #[doc(alias = "get_device_changed")]
     #[doc(alias = "gst_message_parse_device_changed")]
     pub fn device_changed(&self) -> (crate::Device, crate::Device) {
@@ -1613,6 +1692,40 @@ impl<'a> DeviceChanged<'a> {
     }
 }
 
+#[cfg(any(feature = "v1_18", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+declare_concrete_message!(InstantRateRequest);
+#[cfg(any(feature = "v1_18", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+impl<'a> InstantRateRequest<'a> {
+    #[doc(alias = "gst_message_new_instant_rate_request")]
+    #[allow(clippy::new_ret_no_self)]
+    pub fn new(rate_multiplier: f64) -> Message {
+        skip_assert_initialized!();
+        Self::builder(rate_multiplier).build()
+    }
+
+    pub fn builder(rate_multiplier: f64) -> InstantRateRequestBuilder<'a> {
+        assert_initialized_main_thread!();
+        InstantRateRequestBuilder::new(rate_multiplier)
+    }
+
+    #[doc(alias = "parse_instant_rate_request")]
+    #[doc(alias = "gst_message_parse_instant_rate_request")]
+    pub fn rate_multiplier(&self) -> f64 {
+        unsafe {
+            let mut rate_multiplier = mem::MaybeUninit::uninit();
+
+            ffi::gst_message_parse_instant_rate_request(
+                self.as_mut_ptr(),
+                rate_multiplier.as_mut_ptr(),
+            );
+
+            rate_multiplier.assume_init()
+        }
+    }
+}
+
 struct MessageBuilder<'a> {
     src: Option<Object>,
     seqnum: Option<Seqnum>,
@@ -1668,6 +1781,7 @@ macro_rules! message_builder_generic_impl {
             }
         }
 
+        #[doc(alias = "gst_message_set_seqnum")]
         #[allow(clippy::needless_update)]
         pub fn seqnum(self, seqnum: Seqnum) -> Self {
             Self {
@@ -1689,6 +1803,7 @@ macro_rules! message_builder_generic_impl {
             }
         }
 
+        #[must_use = "Building the message without using it has no effect"]
         pub fn build(mut self) -> Message {
             assert_initialized_main_thread!();
             unsafe {
@@ -1717,6 +1832,7 @@ macro_rules! message_builder_generic_impl {
     };
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct EosBuilder<'a> {
     builder: MessageBuilder<'a>,
 }
@@ -1739,6 +1855,7 @@ impl MessageErrorDomain for crate::ResourceError {}
 impl MessageErrorDomain for crate::StreamError {}
 impl MessageErrorDomain for crate::LibraryError {}
 
+#[must_use = "The builder must be built to be used"]
 pub struct ErrorBuilder<'a, T> {
     builder: MessageBuilder<'a>,
     error: T,
@@ -1805,6 +1922,7 @@ impl<'a, T: MessageErrorDomain> ErrorBuilder<'a, T> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct WarningBuilder<'a, T> {
     builder: MessageBuilder<'a>,
     error: T,
@@ -1871,6 +1989,7 @@ impl<'a, T: MessageErrorDomain> WarningBuilder<'a, T> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct InfoBuilder<'a, T> {
     builder: MessageBuilder<'a>,
     error: T,
@@ -1937,6 +2056,7 @@ impl<'a, T: MessageErrorDomain> InfoBuilder<'a, T> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct TagBuilder<'a> {
     builder: MessageBuilder<'a>,
     tags: &'a TagList,
@@ -1957,6 +2077,7 @@ impl<'a> TagBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct BufferingBuilder<'a> {
     builder: MessageBuilder<'a>,
     percent: i32,
@@ -2004,6 +2125,7 @@ impl<'a> BufferingBuilder<'a> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StateChangedBuilder<'a> {
     builder: MessageBuilder<'a>,
     old: crate::State,
@@ -2030,6 +2152,7 @@ impl<'a> StateChangedBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StateDirtyBuilder<'a> {
     builder: MessageBuilder<'a>,
 }
@@ -2045,6 +2168,7 @@ impl<'a> StateDirtyBuilder<'a> {
     message_builder_generic_impl!(|_, src| ffi::gst_message_new_state_dirty(src));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StepDoneBuilder<'a> {
     builder: MessageBuilder<'a>,
     amount: GenericFormattedValue,
@@ -2089,6 +2213,7 @@ impl<'a> StepDoneBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct ClockProvideBuilder<'a> {
     builder: MessageBuilder<'a>,
     clock: &'a crate::Clock,
@@ -2112,6 +2237,7 @@ impl<'a> ClockProvideBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct ClockLostBuilder<'a> {
     builder: MessageBuilder<'a>,
     clock: &'a crate::Clock,
@@ -2132,6 +2258,7 @@ impl<'a> ClockLostBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct NewClockBuilder<'a> {
     builder: MessageBuilder<'a>,
     clock: &'a crate::Clock,
@@ -2152,6 +2279,7 @@ impl<'a> NewClockBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StructureChangeBuilder<'a> {
     builder: MessageBuilder<'a>,
     type_: crate::StructureChangeType,
@@ -2178,6 +2306,7 @@ impl<'a> StructureChangeBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StreamStatusBuilder<'a> {
     builder: MessageBuilder<'a>,
     type_: crate::StreamStatusType,
@@ -2216,6 +2345,7 @@ impl<'a> StreamStatusBuilder<'a> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct ApplicationBuilder<'a> {
     builder: MessageBuilder<'a>,
     structure: Option<crate::Structure>,
@@ -2236,6 +2366,7 @@ impl<'a> ApplicationBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct ElementBuilder<'a> {
     builder: MessageBuilder<'a>,
     structure: Option<crate::Structure>,
@@ -2256,6 +2387,7 @@ impl<'a> ElementBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct SegmentStartBuilder<'a> {
     builder: MessageBuilder<'a>,
     position: GenericFormattedValue,
@@ -2277,6 +2409,7 @@ impl<'a> SegmentStartBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct SegmentDoneBuilder<'a> {
     builder: MessageBuilder<'a>,
     position: GenericFormattedValue,
@@ -2298,6 +2431,7 @@ impl<'a> SegmentDoneBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct DurationChangedBuilder<'a> {
     builder: MessageBuilder<'a>,
 }
@@ -2313,6 +2447,7 @@ impl<'a> DurationChangedBuilder<'a> {
     message_builder_generic_impl!(|_, src| ffi::gst_message_new_duration_changed(src));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct LatencyBuilder<'a> {
     builder: MessageBuilder<'a>,
 }
@@ -2328,6 +2463,7 @@ impl<'a> LatencyBuilder<'a> {
     message_builder_generic_impl!(|_, src| ffi::gst_message_new_latency(src));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct AsyncStartBuilder<'a> {
     builder: MessageBuilder<'a>,
 }
@@ -2343,6 +2479,7 @@ impl<'a> AsyncStartBuilder<'a> {
     message_builder_generic_impl!(|_, src| ffi::gst_message_new_async_start(src));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct AsyncDoneBuilder<'a> {
     builder: MessageBuilder<'a>,
     running_time: Option<crate::ClockTime>,
@@ -2368,6 +2505,7 @@ impl<'a> AsyncDoneBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct RequestStateBuilder<'a> {
     builder: MessageBuilder<'a>,
     state: crate::State,
@@ -2388,6 +2526,7 @@ impl<'a> RequestStateBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StepStartBuilder<'a> {
     builder: MessageBuilder<'a>,
     active: bool,
@@ -2427,6 +2566,7 @@ impl<'a> StepStartBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct QosBuilder<'a> {
     builder: MessageBuilder<'a>,
     live: bool,
@@ -2514,6 +2654,7 @@ impl<'a> QosBuilder<'a> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct ProgressBuilder<'a> {
     builder: MessageBuilder<'a>,
     type_: crate::ProgressType,
@@ -2540,6 +2681,7 @@ impl<'a> ProgressBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct TocBuilder<'a> {
     builder: MessageBuilder<'a>,
     toc: &'a crate::Toc,
@@ -2563,6 +2705,7 @@ impl<'a> TocBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct ResetTimeBuilder<'a> {
     builder: MessageBuilder<'a>,
     running_time: crate::ClockTime,
@@ -2583,6 +2726,7 @@ impl<'a> ResetTimeBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct StreamStartBuilder<'a> {
     builder: MessageBuilder<'a>,
     group_id: Option<GroupId>,
@@ -2613,6 +2757,7 @@ impl<'a> StreamStartBuilder<'a> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct NeedContextBuilder<'a> {
     builder: MessageBuilder<'a>,
     context_type: &'a str,
@@ -2633,6 +2778,7 @@ impl<'a> NeedContextBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct HaveContextBuilder<'a> {
     builder: MessageBuilder<'a>,
     context: Option<crate::Context>,
@@ -2653,6 +2799,7 @@ impl<'a> HaveContextBuilder<'a> {
     });
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct DeviceAddedBuilder<'a> {
     builder: MessageBuilder<'a>,
     device: &'a crate::Device,
@@ -2673,6 +2820,7 @@ impl<'a> DeviceAddedBuilder<'a> {
     ));
 }
 
+#[must_use = "The builder must be built to be used"]
 pub struct DeviceRemovedBuilder<'a> {
     builder: MessageBuilder<'a>,
     device: &'a crate::Device,
@@ -2695,6 +2843,7 @@ impl<'a> DeviceRemovedBuilder<'a> {
 
 #[cfg(any(feature = "v1_10", feature = "dox"))]
 #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+#[must_use = "The builder must be built to be used"]
 pub struct PropertyNotifyBuilder<'a> {
     builder: MessageBuilder<'a>,
     property_name: &'a str,
@@ -2736,6 +2885,7 @@ impl<'a> PropertyNotifyBuilder<'a> {
 
 #[cfg(any(feature = "v1_10", feature = "dox"))]
 #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+#[must_use = "The builder must be built to be used"]
 pub struct StreamCollectionBuilder<'a> {
     builder: MessageBuilder<'a>,
     collection: &'a crate::StreamCollection,
@@ -2759,6 +2909,7 @@ impl<'a> StreamCollectionBuilder<'a> {
 
 #[cfg(any(feature = "v1_10", feature = "dox"))]
 #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+#[must_use = "The builder must be built to be used"]
 pub struct StreamsSelectedBuilder<'a> {
     builder: MessageBuilder<'a>,
     #[cfg(any(feature = "v1_10", feature = "dox"))]
@@ -2801,6 +2952,7 @@ impl<'a> StreamsSelectedBuilder<'a> {
 
 #[cfg(any(feature = "v1_10", feature = "dox"))]
 #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_10")))]
+#[must_use = "The builder must be built to be used"]
 pub struct RedirectBuilder<'a> {
     builder: MessageBuilder<'a>,
     location: &'a str,
@@ -2885,6 +3037,7 @@ impl<'a> RedirectBuilder<'a> {
 
 #[cfg(any(feature = "v1_16", feature = "dox"))]
 #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[must_use = "The builder must be built to be used"]
 pub struct DeviceChangedBuilder<'a> {
     builder: MessageBuilder<'a>,
     device: &'a crate::Device,
@@ -2910,6 +3063,30 @@ impl<'a> DeviceChangedBuilder<'a> {
     ));
 }
 
+#[cfg(any(feature = "v1_18", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+#[must_use = "The builder must be built to be used"]
+pub struct InstantRateRequestBuilder<'a> {
+    builder: MessageBuilder<'a>,
+    rate_multiplier: f64,
+}
+
+#[cfg(any(feature = "v1_18", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+impl<'a> InstantRateRequestBuilder<'a> {
+    fn new(rate_multiplier: f64) -> Self {
+        skip_assert_initialized!();
+        Self {
+            builder: MessageBuilder::new(),
+            rate_multiplier,
+        }
+    }
+
+    message_builder_generic_impl!(
+        |s: &mut Self, src| ffi::gst_message_new_instant_rate_request(src, s.rate_multiplier,)
+    );
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
