@@ -1,12 +1,13 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
+use super::prelude::*;
 use glib::prelude::*;
 use glib::subclass::prelude::*;
 use glib::translate::*;
 
 use crate::ChildProxy;
 
-pub trait ChildProxyImpl: ObjectImpl + Send + Sync {
+pub trait ChildProxyImpl: GstObjectImpl + Send + Sync {
     fn child_by_name(&self, object: &Self::Type, name: &str) -> Option<glib::Object> {
         self.parent_child_by_name(object, name)
     }
@@ -123,8 +124,6 @@ unsafe impl<T: ChildProxyImpl> IsImplementable<T> for ChildProxy {
         iface.child_added = Some(child_proxy_child_added::<T>);
         iface.child_removed = Some(child_proxy_child_removed::<T>);
     }
-
-    fn instance_init(_instance: &mut glib::subclass::InitializingObject<T>) {}
 }
 
 unsafe extern "C" fn child_proxy_get_child_by_name<T: ChildProxyImpl>(
@@ -132,7 +131,7 @@ unsafe extern "C" fn child_proxy_get_child_by_name<T: ChildProxyImpl>(
     name: *const libc::c_char,
 ) -> *mut glib::gobject_ffi::GObject {
     let instance = &*(child_proxy as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     imp.child_by_name(
         from_glib_borrow::<_, ChildProxy>(child_proxy).unsafe_cast_ref(),
@@ -146,7 +145,7 @@ unsafe extern "C" fn child_proxy_get_child_by_index<T: ChildProxyImpl>(
     index: u32,
 ) -> *mut glib::gobject_ffi::GObject {
     let instance = &*(child_proxy as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     imp.child_by_index(
         from_glib_borrow::<_, ChildProxy>(child_proxy).unsafe_cast_ref(),
@@ -159,7 +158,7 @@ unsafe extern "C" fn child_proxy_get_children_count<T: ChildProxyImpl>(
     child_proxy: *mut ffi::GstChildProxy,
 ) -> u32 {
     let instance = &*(child_proxy as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     imp.children_count(from_glib_borrow::<_, ChildProxy>(child_proxy).unsafe_cast_ref())
 }
@@ -170,7 +169,7 @@ unsafe extern "C" fn child_proxy_child_added<T: ChildProxyImpl>(
     name: *const libc::c_char,
 ) {
     let instance = &*(child_proxy as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     imp.child_added(
         from_glib_borrow::<_, ChildProxy>(child_proxy).unsafe_cast_ref(),
@@ -185,7 +184,7 @@ unsafe extern "C" fn child_proxy_child_removed<T: ChildProxyImpl>(
     name: *const libc::c_char,
 ) {
     let instance = &*(child_proxy as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     imp.child_removed(
         from_glib_borrow::<_, ChildProxy>(child_proxy).unsafe_cast_ref(),
