@@ -102,8 +102,6 @@ unsafe impl<T: URIHandlerImpl> IsImplementable<T> for URIHandler {
         iface.get_uri = Some(uri_handler_get_uri::<T>);
         iface.set_uri = Some(uri_handler_set_uri::<T>);
     }
-
-    fn instance_init(_instance: &mut glib::subclass::InitializingObject<T>) {}
 }
 
 unsafe extern "C" fn uri_handler_get_type<T: URIHandlerImpl>(
@@ -126,7 +124,7 @@ unsafe extern "C" fn uri_handler_get_uri<T: URIHandlerImpl>(
     uri_handler: *mut ffi::GstURIHandler,
 ) -> *mut libc::c_char {
     let instance = &*(uri_handler as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     imp.uri(from_glib_borrow::<_, URIHandler>(uri_handler).unsafe_cast_ref())
         .to_glib_full()
@@ -138,7 +136,7 @@ unsafe extern "C" fn uri_handler_set_uri<T: URIHandlerImpl>(
     err: *mut *mut glib::ffi::GError,
 ) -> glib::ffi::gboolean {
     let instance = &*(uri_handler as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
 
     match imp.set_uri(
         from_glib_borrow::<_, URIHandler>(uri_handler).unsafe_cast_ref(),
