@@ -1,7 +1,6 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 use num_rational::Rational32;
-use std::borrow::{Borrow, Cow};
 use std::cmp;
 use std::fmt;
 use std::ops;
@@ -29,6 +28,14 @@ impl Fraction {
         assert_initialized_main_thread!();
         Rational32::approximate_float(x).map(|r| r.into())
     }
+
+    pub fn numer(&self) -> i32 {
+        *self.0.numer()
+    }
+
+    pub fn denom(&self) -> i32 {
+        *self.0.denom()
+    }
 }
 
 impl fmt::Display for Fraction {
@@ -264,7 +271,7 @@ impl glib::value::ToValue for Fraction {
     fn to_value(&self) -> glib::Value {
         let mut value = glib::Value::for_value_type::<Self>();
         unsafe {
-            ffi::gst_value_set_fraction(value.to_glib_none_mut().0, *self.numer(), *self.denom());
+            ffi::gst_value_set_fraction(value.to_glib_none_mut().0, self.numer(), self.denom());
         }
         value
     }
@@ -296,35 +303,53 @@ impl<T: Copy> IntRange<T> {
     }
 }
 
-impl IntRange<i32> {
-    pub fn new(min: i32, max: i32) -> Self {
+#[doc(hidden)]
+pub trait IntRangeType: Sized + Clone + Copy + 'static {
+    fn with_min_max(min: Self, max: Self) -> IntRange<Self>;
+    fn with_step(min: Self, max: Self, step: Self) -> IntRange<Self>;
+}
+
+impl IntRangeType for i32 {
+    fn with_min_max(min: i32, max: i32) -> IntRange<Self> {
         skip_assert_initialized!();
-        Self::with_step(min, max, 1)
+        IntRange { min, max, step: 1 }
     }
 
-    pub fn with_step(min: i32, max: i32, step: i32) -> Self {
+    fn with_step(min: i32, max: i32, step: i32) -> IntRange<Self> {
         assert_initialized_main_thread!();
 
         assert!(min <= max);
         assert!(step > 0);
 
-        Self { min, max, step }
+        IntRange { min, max, step }
     }
 }
 
-impl IntRange<i64> {
-    pub fn new(min: i64, max: i64) -> Self {
+impl IntRangeType for i64 {
+    fn with_min_max(min: i64, max: i64) -> IntRange<Self> {
         skip_assert_initialized!();
-        Self::with_step(min, max, 1)
+        IntRange { min, max, step: 1 }
     }
 
-    pub fn with_step(min: i64, max: i64, step: i64) -> Self {
+    fn with_step(min: i64, max: i64, step: i64) -> IntRange<Self> {
         assert_initialized_main_thread!();
 
         assert!(min <= max);
         assert!(step > 0);
 
-        Self { min, max, step }
+        IntRange { min, max, step }
+    }
+}
+
+impl<T: IntRangeType> IntRange<T> {
+    pub fn new(min: T, max: T) -> IntRange<T> {
+        assert_initialized_main_thread!();
+        T::with_min_max(min, max)
+    }
+
+    pub fn with_step(min: T, max: T, step: T) -> IntRange<T> {
+        assert_initialized_main_thread!();
+        T::with_step(min, max, step)
     }
 }
 
@@ -509,10 +534,10 @@ impl glib::value::ToValue for FractionRange {
         unsafe {
             ffi::gst_value_set_fraction_range_full(
                 value.to_glib_none_mut().0,
-                *self.min().numer(),
-                *self.min().denom(),
-                *self.max().numer(),
-                *self.max().denom(),
+                self.min().numer(),
+                self.min().denom(),
+                self.max().numer(),
+                self.max().denom(),
             );
         }
         value
@@ -622,80 +647,84 @@ impl glib::value::ToValue for Bitmask {
 }
 
 #[derive(Clone, Debug)]
-pub struct Array<'a>(Cow<'a, [glib::SendValue]>);
+pub struct Array(Vec<glib::SendValue>);
 
-unsafe impl<'a> Send for Array<'a> {}
-unsafe impl<'a> Sync for Array<'a> {}
+unsafe impl Send for Array {}
+unsafe impl Sync for Array {}
 
-impl<'a> Array<'a> {
-    pub fn new(values: &[&(dyn ToSendValue + Sync)]) -> Self {
+impl Array {
+    pub fn new(values: impl IntoIterator<Item = impl ToSendValue + Sync>) -> Self {
         assert_initialized_main_thread!();
 
-        Array(values.iter().map(|v| v.to_send_value()).collect())
+        Self(values.into_iter().map(|v| v.to_send_value()).collect())
     }
 
-    pub fn from_borrowed<T: AsRef<[glib::SendValue]>>(values: &'a T) -> Self {
+    pub fn from_values(values: impl IntoIterator<Item = glib::SendValue>) -> Self {
         assert_initialized_main_thread!();
 
-        Array(Cow::Borrowed(values.as_ref()))
-    }
-
-    pub fn from_owned(values: Vec<glib::SendValue>) -> Self {
-        assert_initialized_main_thread!();
-
-        Array(Cow::Owned(values))
-    }
-
-    pub fn into_owned(self) -> Array<'static> {
-        Array(self.0.into_owned().into())
+        Self(values.into_iter().collect())
     }
 
     pub fn as_slice(&self) -> &[glib::SendValue] {
-        self.0.borrow()
+        self.0.as_slice()
     }
 }
 
-impl<'a> From<&'a [&'a (dyn ToSendValue + Sync)]> for Array<'a> {
-    fn from(values: &'a [&'a (dyn ToSendValue + Sync)]) -> Self {
-        skip_assert_initialized!();
+impl ops::Deref for Array {
+    type Target = [glib::SendValue];
 
-        Self::new(values)
+    fn deref(&self) -> &[glib::SendValue] {
+        self.as_slice()
     }
 }
 
-impl<'a> From<&'a [glib::SendValue]> for Array<'a> {
-    fn from(values: &'a [glib::SendValue]) -> Self {
+impl AsRef<[glib::SendValue]> for Array {
+    fn as_ref(&self) -> &[glib::SendValue] {
+        self.as_slice()
+    }
+}
+
+impl std::iter::FromIterator<glib::SendValue> for Array {
+    fn from_iter<T: IntoIterator<Item = glib::SendValue>>(iter: T) -> Self {
+        assert_initialized_main_thread!();
+        Self::from_values(iter)
+    }
+}
+
+impl From<Vec<glib::SendValue>> for Array {
+    fn from(values: Vec<glib::SendValue>) -> Self {
         assert_initialized_main_thread!();
 
-        Array(Cow::Borrowed(values))
+        Self(values)
     }
 }
 
-impl<'a> glib::value::ValueType for Array<'static> {
+impl glib::value::ValueType for Array {
     type Type = Self;
 }
 
-unsafe impl<'a> glib::value::FromValue<'a> for Array<'a> {
+unsafe impl<'a> glib::value::FromValue<'a> for Array {
     type Checker = glib::value::GenericValueTypeChecker<Self>;
 
     unsafe fn from_value(value: &'a glib::Value) -> Self {
         skip_assert_initialized!();
         let arr = (*value.to_glib_none().0).data[0].v_pointer as *const glib::ffi::GArray;
         if arr.is_null() {
-            Array(Cow::Borrowed(&[]))
+            Self(Vec::new())
         } else {
             #[allow(clippy::cast_ptr_alignment)]
-            Array(Cow::Borrowed(slice::from_raw_parts(
-                (*arr).data as *const glib::SendValue,
-                (*arr).len as usize,
-            )))
+            Self::from_values(
+                slice::from_raw_parts((*arr).data as *const glib::SendValue, (*arr).len as usize)
+                    .iter()
+                    .cloned(),
+            )
         }
     }
 }
 
-impl<'a> glib::value::ToValue for Array<'a> {
+impl glib::value::ToValue for Array {
     fn to_value(&self) -> glib::Value {
-        let mut value = glib::Value::for_value_type::<Array<'static>>();
+        let mut value = glib::Value::for_value_type::<Array>();
         unsafe {
             for v in self.as_slice() {
                 ffi::gst_value_array_append_value(value.to_glib_none_mut().0, v.to_glib_none().0);
@@ -709,87 +738,163 @@ impl<'a> glib::value::ToValue for Array<'a> {
     }
 }
 
-impl<'a> glib::types::StaticType for Array<'a> {
+impl glib::types::StaticType for Array {
     fn static_type() -> glib::types::Type {
         unsafe { from_glib(ffi::gst_value_array_get_type()) }
     }
 }
 
-#[derive(Clone, Debug)]
-pub struct List<'a>(Cow<'a, [glib::SendValue]>);
+#[derive(Debug, Clone)]
+pub struct ArrayRef<'a>(&'a [glib::SendValue]);
 
-unsafe impl<'a> Send for List<'a> {}
-unsafe impl<'a> Sync for List<'a> {}
+unsafe impl<'a> Send for ArrayRef<'a> {}
+unsafe impl<'a> Sync for ArrayRef<'a> {}
 
-impl<'a> List<'a> {
-    pub fn new(values: &[&(dyn ToSendValue + Sync)]) -> Self {
+impl<'a> ArrayRef<'a> {
+    pub fn new(values: &'a [glib::SendValue]) -> Self {
         assert_initialized_main_thread!();
 
-        List(values.iter().map(|v| v.to_send_value()).collect())
+        Self(values)
     }
 
-    pub fn from_borrowed<T: AsRef<[glib::SendValue]>>(values: &'a T) -> Self {
-        assert_initialized_main_thread!();
-
-        List(Cow::Borrowed(values.as_ref()))
-    }
-
-    pub fn from_owned(values: Vec<glib::SendValue>) -> Self {
-        assert_initialized_main_thread!();
-
-        List(Cow::Owned(values))
-    }
-
-    pub fn into_owned(self) -> List<'static> {
-        List(self.0.into_owned().into())
-    }
-
-    pub fn as_slice(&self) -> &[glib::SendValue] {
-        self.0.borrow()
+    pub fn as_slice(&self) -> &'a [glib::SendValue] {
+        self.0
     }
 }
 
-impl<'a> From<&'a [&'a (dyn ToSendValue + Sync)]> for List<'a> {
-    fn from(values: &'a [&'a (dyn ToSendValue + Sync)]) -> Self {
-        skip_assert_initialized!();
+impl<'a> ops::Deref for ArrayRef<'a> {
+    type Target = [glib::SendValue];
 
-        Self::new(values)
+    fn deref(&self) -> &[glib::SendValue] {
+        self.as_slice()
     }
 }
 
-impl<'a> From<&'a [glib::SendValue]> for List<'a> {
-    fn from(values: &'a [glib::SendValue]) -> Self {
-        assert_initialized_main_thread!();
-
-        List(Cow::Borrowed(values))
+impl<'a> AsRef<[glib::SendValue]> for ArrayRef<'a> {
+    fn as_ref(&self) -> &[glib::SendValue] {
+        self.as_slice()
     }
 }
 
-impl glib::value::ValueType for List<'static> {
-    type Type = Self;
-}
-
-unsafe impl<'a> glib::value::FromValue<'a> for List<'a> {
+unsafe impl<'a> glib::value::FromValue<'a> for ArrayRef<'a> {
     type Checker = glib::value::GenericValueTypeChecker<Self>;
 
     unsafe fn from_value(value: &'a glib::Value) -> Self {
         skip_assert_initialized!();
         let arr = (*value.to_glib_none().0).data[0].v_pointer as *const glib::ffi::GArray;
         if arr.is_null() {
-            List(Cow::Borrowed(&[]))
+            Self(&[])
         } else {
             #[allow(clippy::cast_ptr_alignment)]
-            List(Cow::Borrowed(slice::from_raw_parts(
+            Self(slice::from_raw_parts(
                 (*arr).data as *const glib::SendValue,
                 (*arr).len as usize,
-            )))
+            ))
         }
     }
 }
 
-impl<'a> glib::value::ToValue for List<'a> {
+impl<'a> glib::value::ToValue for ArrayRef<'a> {
     fn to_value(&self) -> glib::Value {
-        let mut value = glib::Value::for_value_type::<List<'static>>();
+        let mut value = glib::Value::for_value_type::<Array>();
+        unsafe {
+            for v in self.0 {
+                ffi::gst_value_array_append_value(value.to_glib_none_mut().0, v.to_glib_none().0);
+            }
+        }
+        value
+    }
+
+    fn value_type(&self) -> glib::Type {
+        Self::static_type()
+    }
+}
+
+impl<'a> glib::types::StaticType for ArrayRef<'a> {
+    fn static_type() -> glib::types::Type {
+        unsafe { from_glib(ffi::gst_value_array_get_type()) }
+    }
+}
+
+#[derive(Clone, Debug)]
+pub struct List(Vec<glib::SendValue>);
+
+unsafe impl Send for List {}
+unsafe impl Sync for List {}
+
+impl List {
+    pub fn new(values: impl IntoIterator<Item = impl ToSendValue + Sync>) -> Self {
+        assert_initialized_main_thread!();
+
+        Self(values.into_iter().map(|v| v.to_send_value()).collect())
+    }
+
+    pub fn from_values(values: impl IntoIterator<Item = glib::SendValue>) -> Self {
+        assert_initialized_main_thread!();
+
+        Self(values.into_iter().collect())
+    }
+
+    pub fn as_slice(&self) -> &[glib::SendValue] {
+        self.0.as_slice()
+    }
+}
+
+impl ops::Deref for List {
+    type Target = [glib::SendValue];
+
+    fn deref(&self) -> &[glib::SendValue] {
+        self.as_slice()
+    }
+}
+
+impl AsRef<[glib::SendValue]> for List {
+    fn as_ref(&self) -> &[glib::SendValue] {
+        self.as_slice()
+    }
+}
+
+impl std::iter::FromIterator<glib::SendValue> for List {
+    fn from_iter<T: IntoIterator<Item = glib::SendValue>>(iter: T) -> Self {
+        assert_initialized_main_thread!();
+        Self::from_values(iter)
+    }
+}
+
+impl From<Vec<glib::SendValue>> for List {
+    fn from(values: Vec<glib::SendValue>) -> Self {
+        assert_initialized_main_thread!();
+
+        Self(values)
+    }
+}
+
+impl glib::value::ValueType for List {
+    type Type = Self;
+}
+
+unsafe impl<'a> glib::value::FromValue<'a> for List {
+    type Checker = glib::value::GenericValueTypeChecker<Self>;
+
+    unsafe fn from_value(value: &'a glib::Value) -> Self {
+        skip_assert_initialized!();
+        let arr = (*value.to_glib_none().0).data[0].v_pointer as *const glib::ffi::GArray;
+        if arr.is_null() {
+            Self(Vec::new())
+        } else {
+            #[allow(clippy::cast_ptr_alignment)]
+            Self::from_values(
+                slice::from_raw_parts((*arr).data as *const glib::SendValue, (*arr).len as usize)
+                    .iter()
+                    .cloned(),
+            )
+        }
+    }
+}
+
+impl glib::value::ToValue for List {
+    fn to_value(&self) -> glib::Value {
+        let mut value = glib::Value::for_value_type::<List>();
         unsafe {
             for v in self.as_slice() {
                 ffi::gst_value_list_append_value(value.to_glib_none_mut().0, v.to_glib_none().0);
@@ -803,7 +908,79 @@ impl<'a> glib::value::ToValue for List<'a> {
     }
 }
 
-impl<'a> glib::types::StaticType for List<'a> {
+impl glib::types::StaticType for List {
+    fn static_type() -> glib::types::Type {
+        unsafe { from_glib(ffi::gst_value_list_get_type()) }
+    }
+}
+
+#[derive(Debug, Clone)]
+pub struct ListRef<'a>(&'a [glib::SendValue]);
+
+unsafe impl<'a> Send for ListRef<'a> {}
+unsafe impl<'a> Sync for ListRef<'a> {}
+
+impl<'a> ListRef<'a> {
+    pub fn new(values: &'a [glib::SendValue]) -> Self {
+        assert_initialized_main_thread!();
+
+        Self(values)
+    }
+
+    pub fn as_slice(&self) -> &'a [glib::SendValue] {
+        self.0
+    }
+}
+
+impl<'a> ops::Deref for ListRef<'a> {
+    type Target = [glib::SendValue];
+
+    fn deref(&self) -> &[glib::SendValue] {
+        self.as_slice()
+    }
+}
+
+impl<'a> AsRef<[glib::SendValue]> for ListRef<'a> {
+    fn as_ref(&self) -> &[glib::SendValue] {
+        self.as_slice()
+    }
+}
+
+unsafe impl<'a> glib::value::FromValue<'a> for ListRef<'a> {
+    type Checker = glib::value::GenericValueTypeChecker<Self>;
+
+    unsafe fn from_value(value: &'a glib::Value) -> Self {
+        skip_assert_initialized!();
+        let arr = (*value.to_glib_none().0).data[0].v_pointer as *const glib::ffi::GArray;
+        if arr.is_null() {
+            Self(&[])
+        } else {
+            #[allow(clippy::cast_ptr_alignment)]
+            Self(slice::from_raw_parts(
+                (*arr).data as *const glib::SendValue,
+                (*arr).len as usize,
+            ))
+        }
+    }
+}
+
+impl<'a> glib::value::ToValue for ListRef<'a> {
+    fn to_value(&self) -> glib::Value {
+        let mut value = glib::Value::for_value_type::<List>();
+        unsafe {
+            for v in self.0 {
+                ffi::gst_value_list_append_value(value.to_glib_none_mut().0, v.to_glib_none().0);
+            }
+        }
+        value
+    }
+
+    fn value_type(&self) -> glib::Type {
+        Self::static_type()
+    }
+}
+
+impl<'a> glib::types::StaticType for ListRef<'a> {
     fn static_type() -> glib::types::Type {
         unsafe { from_glib(ffi::gst_value_list_get_type()) }
     }
@@ -836,7 +1013,14 @@ pub trait GstValueExt: Sized {
     #[doc(alias = "gst_value_serialize")]
     fn serialize(&self) -> Result<glib::GString, glib::BoolError>;
     #[doc(alias = "gst_value_deserialize")]
-    fn deserialize<'a, T: Into<&'a str>>(s: T) -> Result<glib::Value, glib::BoolError>;
+    fn deserialize(s: &str, type_: glib::Type) -> Result<glib::Value, glib::BoolError>;
+    #[cfg(any(feature = "v1_20", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    #[doc(alias = "gst_value_deserialize_with_pspec")]
+    fn deserialize_with_pspec(
+        s: &str,
+        pspec: &glib::ParamSpec,
+    ) -> Result<glib::Value, glib::BoolError>;
 }
 
 impl GstValueExt for glib::Value {
@@ -976,13 +1160,11 @@ impl GstValueExt for glib::Value {
         }
     }
 
-    fn deserialize<'a, T: Into<&'a str>>(s: T) -> Result<glib::Value, glib::BoolError> {
+    fn deserialize(s: &str, type_: glib::Type) -> Result<glib::Value, glib::BoolError> {
         assert_initialized_main_thread!();
 
-        let s = s.into();
-
         unsafe {
-            let mut value = glib::Value::uninitialized();
+            let mut value = glib::Value::from_type(type_);
             let ret: bool = from_glib(ffi::gst_value_deserialize(
                 value.to_glib_none_mut().0,
                 s.to_glib_none().0,
@@ -994,10 +1176,35 @@ impl GstValueExt for glib::Value {
             }
         }
     }
+
+    #[cfg(any(feature = "v1_20", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    fn deserialize_with_pspec(
+        s: &str,
+        pspec: &glib::ParamSpec,
+    ) -> Result<glib::Value, glib::BoolError> {
+        assert_initialized_main_thread!();
+
+        unsafe {
+            let mut value = glib::Value::from_type(pspec.value_type());
+            let ret: bool = from_glib(ffi::gst_value_deserialize_with_pspec(
+                value.to_glib_none_mut().0,
+                s.to_glib_none().0,
+                pspec.to_glib_none().0,
+            ));
+            if ret {
+                Ok(value)
+            } else {
+                Err(glib::bool_error!("Failed to deserialize value"))
+            }
+        }
+    }
 }
 
 #[cfg(test)]
 mod tests {
+    use super::*;
+
     #[test]
     fn test_fraction() {
         crate::init().unwrap();
@@ -1011,4 +1218,21 @@ mod tests {
 
         assert_eq!(f3, crate::Fraction::new(2, 27));
     }
+
+    #[test]
+    fn test_int_range_constructor() {
+        crate::init().unwrap();
+
+        // Type inference should figure out the type
+        let _r1 = crate::IntRange::new(1i32, 2i32);
+        let _r2 = crate::IntRange::with_step(2i64, 3i64, 4i64);
+    }
+
+    #[test]
+    fn test_deserialize() {
+        crate::init().unwrap();
+
+        let v = glib::Value::deserialize("123", i32::static_type()).unwrap();
+        assert_eq!(v.get::<i32>(), Ok(123));
+    }
 }
